@@ -1,4 +1,6 @@
 package Proch::Seqfu;
+#ABSTRACT: Helper module to support Seqfu tools
+
 use 5.014;
 use warnings;
 use Carp qw(confess);
@@ -6,7 +8,7 @@ use Data::Dumper;
 use Term::ANSIColor qw(:constants);
 require Exporter;
 
-$Proch::SeqFu::VERSION = '1.5.0';
+$Proch::SeqFu::VERSION = '1.5.1';
 $Proch::SeqFu::fu_linesize = 0;
 $Proch::SeqFu::fu_verbose  = 0;
 
@@ -84,11 +86,11 @@ sub split_string {
 
 =head1 NAME
 
-Proch::Seqfu
+Proch::Seqfu - Helper module to support Seqfu tools
 
 =head1 VERSION
 
-version 1.4.7
+version 1.4.8
 
 =head1 Proch::Seqfu
 
